const canvas = document.getElementById('network-canvas');
const ctx = canvas.getContext('2d');

const nodes = [
  { id: 'Alice', x: 50, y: 100 },
  { id: 'Bob', x: 200, y: 50 },
  { id: 'Charlie', x: 350, y: 100 },
  { id: 'David', x: 200, y: 200 },
  { id: 'Eve', x: 500, y: 150 },
  { id: 'Frank', x: 650, y: 200 },
  { id: 'Gina', x: 500, y: 250 },
  { id: 'Harry', x: 350, y: 300 },
  { id: 'Ivy', x: 50, y: 250 },
  { id: 'Jack', x: 50, y: 50 },
];

const links = [
  { source: 'Alice', target: 'Bob' },
  { source: 'Alice', target: 'Charlie' },
  { source: 'Alice', target: 'Ivy' },
  { source: 'Bob', target: 'David' },
  { source: 'Charlie', target: 'Eve' },
  { source: 'David', target: 'Eve' },
  { source: 'Eve', target: 'Frank' },
  { source: 'Eve', target: 'Gina' },
  { source: 'Frank', target: 'Harry' },
  { source: 'Gina', target: 'Bob' },
  { source: 'Gina', target: 'Charlie' },
  { source: 'Harry', target: 'David' },
  { source: 'Harry', target: 'Eve' },
  { source: 'Jack', target: 'Charlie' },
  { source: 'Jack', target: 'Eve' },
  { source: 'Jack', target: 'Harry' },
];

function drawNodes() {
  nodes.forEach((node) => {
    ctx.beginPath();
    ctx.arc(node.x, node.y, 20, 0, 2 * Math.PI);
    ctx.fillStyle = '#4682B4'; // Change node color
    ctx.fill();
    ctx.fillStyle = 'white';
    ctx.font = '14px Arial';
    ctx.textAlign = 'center';
    ctx.textBaseline = 'middle';
    ctx.fillText(node.id, node.x, node.y);
  });
}

function drawLinks() {
  links.forEach((link) => {
    const sourceNode = nodes.find(
      (node) => node.id === link.source,
    );
    const targetNode = nodes.find(
      (node) => node.id === link.target,
    );

    ctx.beginPath();
    ctx.moveTo(sourceNode.x, sourceNode.y);
    ctx.lineTo(targetNode.x, targetNode.y);
    ctx.strokeStyle = '#A9A9A9';
    ctx.lineWidth = 2;
    ctx.stroke();
  });
}

function drawGraph() {
  drawLinks();
  drawNodes();
}

function adjustCanvasSize() {
  let maxX = 0;
  let maxY = 0;

  nodes.forEach((node) => {
    if (node.x > maxX) maxX = node.x;
    if (node.y > maxY) maxY = node.y;
  });

  canvas.width = maxX + 50;
  canvas.height = maxY + 50;
}

adjustCanvasSize();
drawGraph();
